@@ -1,10 +1,10 @@
-from gitxray.include import gh_api, gh_time, gh_public_events, gx_definitions
+from gitxray.include import gh_time, gh_public_events, gx_definitions
 from gitxray.include import gx_ugly_openpgp_parser, gx_ugly_ssh_parser 
 from datetime import datetime, timezone
 from collections import defaultdict
 import sys, re, base64
 
-def run(gx_context, gx_output):
+def run(gx_context, gx_output, gh_api):
 
     repository = gx_context.getRepository()
     contributor_scope = gx_context.getContributorScope()
@@ -12,7 +12,7 @@ def run(gx_context, gx_output):
     if contributor_scope != None:
         gx_output.notify(f"YOU HAVE SCOPED THIS GITXRAY TO CONTRIBUTORS: {contributor_scope} - OTHER USERS WON'T BE ANALYZED.")
 
-    print(f"Querying GitHub for repository contributors.. Please wait.", end='', flush=True)
+    gx_output.stdout(f"Querying GitHub for repository contributors.. Please wait.", shushable=True, end='', flush=True)
 
     # Let's store the whole set of contributors in the context
     gx_context.setContributors(gh_api.fetch_repository_contributors(repository))
@@ -21,7 +21,7 @@ def run(gx_context, gx_output):
     c_anon = []
 
     c_len = len(gx_context.getContributors())
-    print(f"\rIdentified {c_len} contributors.." + ' '*70, flush=True)
+    gx_output.stdout(f"\rIdentified {c_len} contributors.." + ' '*70, shushable=True, flush=True)
 
     # If focused on a contributor, let's first make sure the contributor exists in the repository
     if contributor_scope != None:
@@ -32,17 +32,17 @@ def run(gx_context, gx_output):
 
     # Were were invoked to just list contributors and quit?
     if gx_context.listAndQuit():
-        gx_output.notify(f"LISTING CONTRIBUTORS (INCLUDING THOSE WITHOUT A GITHUB USER ACCOUNT) AND EXITING..")
-        print(", ".join([c.get('login', c.get('email')) for c in gx_context.getContributors()]))
+        gx_output.notify(f"LISTING CONTRIBUTORS (INCLUDING THOSE WITHOUT A GITHUB USER ACCOUNT) AND EXITING..", shushable=False)
+        gx_output.stdout(", ".join([c.get('login', c.get('email')) for c in gx_context.getContributors()]), shushable=False)
         return False
 
     if c_len > 500:
-        print(f"IMPORTANT: The repository has 500+ contributors. GitHub states > 500 contributors will appear as Anonymous")
-        print(f"More information at: https://docs.github.com/en/rest/repos/repos?apiVersion=2022-11-28#list-repository-contributors")
+        gx_output.stdout(f"IMPORTANT: The repository has 500+ contributors. GitHub states > 500 contributors will appear as Anonymous")
+        gx_output.stdout(f"More information at: https://docs.github.com/en/rest/repos/repos?apiVersion=2022-11-28#list-repository-contributors")
 
     for i, c in enumerate(gx_context.getContributors()):
         if contributor_scope != None and c.get('login') not in contributor_scope: continue
-        print('\rFetching repository contributor details [{}/{}]'.format(i+1, c_len), end='', flush=True)
+        gx_output.stdout('\rFetching repository contributor details [{}/{}]'.format(i+1, c_len), end='', flush=True)
         ctype = c.get('type')
         if ctype in ["User", "Bot"]:
             c_users.append(gh_api.fetch_contributor(c))
@@ -52,12 +52,12 @@ def run(gx_context, gx_output):
             print(c)
             raise Exception("Contributor of Type !== User/Anonymous found. Failing almost gracefully")
 
-    if contributor_scope == None:
-        print(f"\r\nDiscovered {len(c_users)} contributors with Github User accounts, and {len(c_anon)} Anonymous contributors", end='', flush=True)
+    if contributor_scope == None and len(gx_context.getContributors()) != 0:
+        gx_output.stdout(f"\r\nDiscovered {len(c_users)} contributors with GitHub User accounts, and {len(c_anon)} Anonymous contributors", end='', flush=True)
         gx_output.r_log(f"Repository has {len(c_anon)} Anonymous contributors.", rtype="contributors")
-        gx_output.r_log(f"Repository has {len(c_users)} contributors with Github User accounts.", rtype="contributors")
+        gx_output.r_log(f"Repository has {len(c_users)} contributors with GitHub User accounts.", rtype="contributors")
 
-    print(f"\r\nPlease wait, beginning to collect keys and commits for User contributors..", end='', flush=True)
+    gx_output.stdout(f"\r\nPlease wait, beginning to collect keys and commits for User contributors..", end='', flush=True)
 
     c_users_index = 1
     for contributor in c_users:
@@ -68,7 +68,7 @@ def run(gx_context, gx_output):
         c_started_at = datetime.now()
         gx_output.c_log(f"X-Ray on contributor started at {c_started_at}", contributor=contributor_login, rtype="metrics")
 
-        print(f"\r[{c_users_index}/{len(c_users)}] Analyzing Profile data for {contributor.get('login')}"+' '*40, end = '', flush=True)
+        gx_output.stdout(f"\r[{c_users_index}/{len(c_users)}] Analyzing Profile data for {contributor.get('login')}"+' '*40, end = '', flush=True)
         gx_output.c_log(f"Contributor URL: {contributor.get('html_url')}", rtype="urls")
         gx_output.c_log(f"Owned repositories: https://github.com/{contributor_login}?tab=repositories", rtype="urls")
 
@@ -86,6 +86,8 @@ def run(gx_context, gx_output):
             gx_output.c_log(f"[Blog: {contributor.get('blog')}] obtained from the user's profile.", rtype="personal")
         if contributor.get('location') != None:
             gx_output.c_log(f"[Location: {contributor.get('location')}] obtained from the user's profile.", rtype="personal")
+        if contributor.get('hireable') != None:
+            gx_output.c_log(f"[Hireable: The user has set 'Available for Hire'] in their GitHub profile.", rtype="personal")
 
         if contributor.get('email') != None:
             gx_output.c_log(f"[{contributor.get('email')}] obtained from the user's profile.", rtype="emails")
@@ -126,7 +128,7 @@ def run(gx_context, gx_output):
         signature_attributes = []
         dates_mismatch_commits = []
         commit_times = defaultdict(int)
-        print(f"\r[{c_users_index}/{len(c_users)}] Analyzing {len(commits)} commits and any signing keys for {contributor.get('login')}"+' '*40, end = '', flush=True)
+        gx_output.stdout(f"\r[{c_users_index}/{len(c_users)}] Analyzing {len(commits)} commits and any signing keys for {contributor.get('login')}"+' '*40, end = '', flush=True)
         for commit in commits:
             c = commit["commit"]
 
@@ -204,7 +206,7 @@ def run(gx_context, gx_output):
         unique_pgp_sct = set(attribute.get('pgp_signature_creation_time') for attribute in signature_attributes if attribute.get('pgp_signature_creation_time') is not None)
         unique_pgp_keyids = set(attribute.get('pgp_keyid') for attribute in signature_attributes if attribute.get('pgp_keyid') is not None)
 
-        # We don't link SSH Key IDs because SSH keys are unique across Github; PGP keys can be added to more than 1 account.
+        # We don't link SSH Key IDs because SSH keys are unique across GitHub; PGP keys can be added to more than 1 account.
         gx_context.linkIdentifier("PGP_KEYID", unique_pgp_keyids, contributor_login)
         gx_context.linkIdentifier("PGP_PKA", unique_pgp_pka, contributor_login)
         gx_context.linkIdentifier("PGP_HA", unique_pgp_ha, contributor_login)
@@ -228,7 +230,7 @@ def run(gx_context, gx_output):
 
 
         # https://docs.github.com/en/rest/users/gpg-keys?apiVersion=2022-11-28#list-gpg-keys-for-a-user
-        # Github calls them GPG keys, but we're going to refer to them as PGP for the OpenPGP standard
+        # GitHub calls them GPG keys, but we're going to refer to them as PGP for the OpenPGP standard
         pgp_keys = gh_api.fetch_gpg_keys(contributor_login)
         if pgp_keys != None and len(pgp_keys) > 0:
             primary_key_ids = [key.get('key_id') for key in pgp_keys]
@@ -334,12 +336,12 @@ def run(gx_context, gx_output):
         # Unique key ids for now only holds keys we've extracted from commit signatures
         if len(unique_pgp_keyids) > 0:
             # https://docs.github.com/en/rest/search/search?apiVersion=2022-11-28#constructing-a-search-query
-            # Unfortunately Github requires (for other users than our own) to provide (non-regex) input keywords in order to
+            # Unfortunately GitHub requires (for other users than our own) to provide (non-regex) input keywords in order to
             # return results in the commits API which accept filtering such as is:signed - and input keywords restrict our results.
             gx_output.c_log(f"{len(unique_pgp_keyids)} Keys ({unique_pgp_keyids}) were used by this contributor when signing commits.", rtype="keys")
             github_keys_used = [keyid for keyid in unique_pgp_keyids if keyid in gx_definitions.GITHUB_WEB_EDITOR_SIGNING_KEYS]
             if len(github_keys_used) > 0:
-                gx_output.c_log(f"{len(github_keys_used)} of the keys used to sign commits belong to Github's Web editor {github_keys_used}", rtype="keys")
+                gx_output.c_log(f"{len(github_keys_used)} of the keys used to sign commits belong to GitHub's Web editor {github_keys_used}", rtype="keys")
 
         if len(commits) == len(signed_commits):
             gx_output.c_log(f"Contributor has signed all of their {len(signed_commits)} total commits (to this repo).", rtype="signatures")
@@ -371,7 +373,7 @@ def run(gx_context, gx_output):
             gx_output.c_log(f"One of {contributor_login} emails matched the following anonymous users: {matching_anonymous}", rtype="profiling")
 
 
-        print(f"\r[{c_users_index}/{len(c_users)}] Collecting recent (90d) public events for {contributor.get('login')}"+' '*40, end = '', flush=True)
+        gx_output.stdout(f"\r[{c_users_index}/{len(c_users)}] Collecting recent (90d) public events for {contributor.get('login')}"+' '*40, end = '', flush=True)
 
         # Get Public Events generated by this account, if any. GitHub offers up to 90 days of data, which might still be useful.
         public_events = gh_api.fetch_contributor_events(contributor)
@@ -383,7 +385,7 @@ def run(gx_context, gx_output):
         gx_output.c_log(f"X-Ray on contributor ended at {c_ended_at} - {(c_ended_at-c_started_at).seconds} seconds elapsed", rtype="metrics")
 
     # Let's first create a dictionary merging by email - this is because duplicate anonymous are "normal" or regularly seen
-    # Github checks if any of (email OR name) differ and if so treats the anonymous user as different
+    # GitHub checks if any of (email OR name) differ and if so treats the anonymous user as different
     # Add all of these under Anonymous contributor output
     unique_anonymous = {}
     for ac in c_anon:
@@ -397,6 +399,6 @@ def run(gx_context, gx_output):
     for k,v in unique_anonymous.items():
         gx_output.a_log(f'{k} - {v}', anonymous="#", rtype="anonymous")
 
-    print('\rContributors have been analyzed..'+' '*60, flush=True)
+    gx_output.stdout('\rContributors have been analyzed..'+' '*60, flush=True)
 
     return True
