@@ -1,32 +1,35 @@
 from datetime import datetime, timezone
 from collections import defaultdict
 import math
-from gitxray.include import gh_api, gh_time, gh_public_events, gh_reactions
+from gitxray.include import gh_time, gh_public_events, gh_reactions
 
-def run(gx_context, gx_output):
-    print("Running verifications on the repository..")
+def run(gx_context, gx_output, gh_api):
+    gx_output.stdout("Running verifications on the repository..")
 
     repository = gx_context.getRepository()
     contributors = gx_context.getContributors()
 
-    print(f"Checking for similar repository names in GitHub.."+" "*40, end="")
+    gx_output.stdout(f"Checking for similar repository names in GitHub.."+" "*40, end="")
     # This gets all repository names matching our repository name, sorted first by highest rating
     similar_names = gh_api.search_repositories_by_name(repository.get('name'), limit=10)
     if similar_names != None and similar_names.get('total_count') != None and similar_names.get('total_count') > 0:
         most_rated = similar_names.get('items')[0]
         search_url = f"https://github.com/search?q={repository.get('name')}%20in:name&type=repositories&s=stars&o=desc"
         if most_rated.get('full_name') == repository.get('full_name'):
-            gx_output.r_log(f"This is the highest rating repository with name [{repository.get('name')}]", rtype="profiling")
+            reponame_msg = f"This is the highest rating repository with name [{repository.get('name')}]"
         else:
-            gx_output.r_log(f"WARNING: This is NOT the highest rating repository with name [{repository.get('name')}]", rtype="profiling")
+            reponame_msg = f"WARNING: This is NOT the highest rating repository with name [{repository.get('name')}]"
 
-        if similar_names.get('total_count') > 1:
-            gx_output.r_log(f'{similar_names.get("total_count")} repositories with a similar name were discovered - See them here: {search_url}', 'profiling')
+        if similar_names.get('total_count') > 0:
+            gx_output.r_log(f'{reponame_msg}. {similar_names.get("total_count")} repositories with a similar name were discovered - See them here: {search_url}', 'profiling')
+        else:
+            gx_output.r_log(f'{reponame_msg}', 'profiling')
 
-    stargazers_message = f"Stars count: [{repository.get('stargazers_count')}]"
-    if repository.get('stargazers_count') > 0:
-        stargazers_message += f" List at: {repository.get('stargazers_url')}"
-    gx_output.r_log(stargazers_message, rtype="profiling")
+    if repository.get('stargazers_count') is not None:
+        stargazers_message = f"Stars count: [{repository.get('stargazers_count')}]"
+        if repository.get('stargazers_count', 0) > 0:
+            stargazers_message += f" List at: {repository.get('stargazers_url')}"
+        gx_output.r_log(stargazers_message, rtype="profiling")
 
     if repository.get('owner'):
         gx_output.r_log(f"Repository owner account is [{repository.get('owner').get('login')}]: {repository.get('owner').get('html_url')}", rtype="profiling")
@@ -39,9 +42,9 @@ def run(gx_context, gx_output):
 
     # These go in the repository xray and not contributors because the REST API returns all per repository
     # https://api.github.com/repos/infobyte/faraday/issues/comments - and won't allow filtering in a helpful (to us) way
-    print(f"\rGetting all repository comments on commits.."+" "*40, end="")
+    gx_output.stdout(f"\rGetting all repository comments on commits.."+" "*40, end="")
     commit_comments = gh_api.fetch_repository_commit_comments(repository)
-    if len(commit_comments) > 0: 
+    if isinstance(commit_comments, list) and len(commit_comments) > 0: 
         total_comments = defaultdict(int)
         positive_reactions = defaultdict(int)
         negative_reactions = defaultdict(int)
@@ -49,7 +52,7 @@ def run(gx_context, gx_output):
         for cc in commit_comments:
             gh_reactions.categorize_reactions(cc, positive_reactions, negative_reactions, neutral_reactions)
             login = cc.get('user').get('login')
-            message = f"User {login} added a comment to a Commit on [{cc.get('created_at')}], updated [{cc.get('updated_at')}]: {cc.get('html_url')}"
+            message = (f"User {login} added a comment to a Commit on [{cc.get('created_at')}]" + (f", and then updated it on [{cc.get('updated_at')}]" if cc.get('updated_at') != cc.get('created_at') else "") + f": {cc.get('html_url')}")
             total_comments[login] += 1
             gx_output.c_log(message, rtype="comments", contributor=login)
 
@@ -82,9 +85,9 @@ def run(gx_context, gx_output):
             if count > 0: gx_output.r_log(f"The Commits comment with the most NEUTRAL reactions ({count}) is available at: {url}", rtype="comments")
 
     
-    print(f"\rGetting all repository comments on issues.."+" "*30, end="")
+    gx_output.stdout(f"\rGetting all repository comments on issues.."+" "*30, end="")
     issues_comments = gh_api.fetch_repository_issues_comments(repository)
-    if issues_comments != None and len(issues_comments) > 0: 
+    if isinstance(issues_comments, list) and len(issues_comments) > 0: 
         total_comments = defaultdict(int)
         positive_reactions = defaultdict(int)
         negative_reactions = defaultdict(int)
@@ -92,7 +95,7 @@ def run(gx_context, gx_output):
         for cc in issues_comments:
             gh_reactions.categorize_reactions(cc, positive_reactions, negative_reactions, neutral_reactions)
             login = cc.get('user').get('login')
-            message = f"User [{login}] added a comment to an Issue on [{cc.get('created_at')}], updated [{cc.get('updated_at')}]: {cc.get('html_url')}"
+            message = (f"User {login} added a comment to an Issue on [{cc.get('created_at')}]" + (f", and then updated it on [{cc.get('updated_at')}]" if cc.get('updated_at') != cc.get('created_at') else "") + f": {cc.get('html_url')}")
             total_comments[login] += 1
             gx_output.c_log(message, rtype="comments", contributor=login)
 
@@ -123,9 +126,9 @@ def run(gx_context, gx_output):
             url, count = gh_reactions.sort_reactions(neutral_reactions)[0]
             if count > 0: gx_output.r_log(f"The Issues comment with the most NEUTRAL reactions ({count}) is available at: {url}", rtype="comments")
 
-    print(f"\rGetting all repository comments on pull requests.."+" "*30, end="")
+    gx_output.stdout(f"\rGetting all repository comments on pull requests.."+" "*30, end="")
     pulls_comments = gh_api.fetch_repository_pulls_comments(repository)
-    if pulls_comments != None and len(pulls_comments) > 0: 
+    if isinstance(pulls_comments, list) and len(pulls_comments) > 0: 
         total_comments = defaultdict(int)
         positive_reactions = defaultdict(int)
         negative_reactions = defaultdict(int)
@@ -136,7 +139,7 @@ def run(gx_context, gx_output):
                 login = cc.get('user', {}).get('login', None)
             except:
                 continue
-            message = f"User {login} added a comment to a PR on [{cc.get('created_at')}], updated [{cc.get('updated_at')}]: {cc.get('html_url')}"
+            message = (f"User {login} added a comment to a PR on [{cc.get('created_at')}]" + (f", and then updated it on [{cc.get('updated_at')}]" if cc.get('updated_at') != cc.get('created_at') else "") + f": {cc.get('html_url')}")
             total_comments[login] += 1
             gx_output.c_log(message, rtype="comments", contributor=login)
 
@@ -168,12 +171,12 @@ def run(gx_context, gx_output):
             if count > 0: gx_output.r_log(f"The PRs comment with the most NEUTRAL reactions ({count}) is available at: {url}", rtype="comments")
 
 
-    print(f"\rChecking for repository deployments.."+" "*30, end="")
+    gx_output.stdout(f"\rChecking for repository deployments.."+" "*30, end="")
     if repository.get('deployments_url'):
          deployments = gh_api.fetch_repository_deployments(repository)
          if len(deployments) > 0: gx_output.r_log(f"{len(deployments)} Deployments available at: [{repository.get('html_url')}/deployments]", rtype="deployments")
 
-    print(f"\rChecking for repository environments.."+" "*30, end="")
+    gx_output.stdout(f"\rChecking for repository environments.."+" "*30, end="")
     environments = gh_api.fetch_repository_environments(repository)
     if environments != None and environments.get('total_count') != None and environments.get('total_count') > 0:
         gx_output.r_log(f"{environments.get('total_count')} Environments available at: [{repository.get('url')}/environments]", rtype="environments")
@@ -181,13 +184,13 @@ def run(gx_context, gx_output):
             gx_output.r_log(f"Environment [{environment.get('name')}] created [{environment.get('created_at')}], updated [{environment.get('updated_at')}]: {environment.get('html_url')}", rtype="environments")
             #print(gh_api.fetch_environment_protection_rules(repository, environment.get('name')))
 
-    print(f"\rChecking for repository forks.."+" "*30, end="")
-    if repository.get('forks_count') > 0:
+    gx_output.stdout(f"\rChecking for repository forks.."+" "*30, end="")
+    if repository.get('forks_count', 0) > 0:
         gx_output.r_log(f"Repository has {repository.get('forks_count')} forks: {repository.get('forks_url')}", rtype="profiling")
 
-    print(f"\rInspecting repository branches.."+" "*40, end="")
+    gx_output.stdout(f"\rInspecting repository branches.."+" "*40, end="")
     branches = gh_api.fetch_repository_branches(repository)
-    if branches != None and len(branches) > 0: 
+    if isinstance(branches, list) and len(branches) > 0: 
         gx_output.r_log(f"{len(branches)} Branches available at: [{repository.get('html_url')}/branches]", rtype="branches")
         unprotected_branches = []
         protected_branches = []
@@ -200,17 +203,20 @@ def run(gx_context, gx_output):
         if len(unprotected_branches) > 0: gx_output.r_log(f"{len(unprotected_branches)} Unprotected Branches: {unprotected_branches}", rtype="branches")
         if len(protected_branches) > 0: gx_output.r_log(f"{len(protected_branches)} Protected Branches: {protected_branches}", rtype="branches")
 
-    print(f"\rInspecting repository labels.."+" "*40, end="")
+    gx_output.stdout(f"\rInspecting repository labels.."+" "*40, end="")
     labels = gh_api.fetch_repository_labels(repository)
-    if labels != None and len(labels) > 0: 
+    if isinstance(labels, list) and len(labels) > 0: 
         gx_output.r_log(f"{len(labels)} Labels available at: [{repository.get('html_url')}/labels]", rtype="labels")
         non_default_labels = [label.get('name') for label in labels if label.get('default') == False]
         if len(non_default_labels) > 0:
             gx_output.r_log(f"{len(non_default_labels)} Non-default Labels: {non_default_labels} available at: [{repository.get('html_url')}/labels]", rtype="labels")
 
-    print(f"\rInspecting repository tags.."+" "*40, end="")
+    gx_output.stdout(f"\rInspecting repository tags.."+" "*40, end="")
     tags = gh_api.fetch_repository_tags(repository)
-    if tags != None and len(tags) > 0: gx_output.r_log(f"{len(tags)} Tags available at: [{repository.get('html_url')}/tags]", rtype="tags")
+    if isinstance(tags, list) and len(tags) > 0: 
+        gx_output.r_log(f"{len(tags)} Tags available at: [{repository.get('html_url')}/tags]", rtype="tags")
+    else:
+        tags = []
     tag_taggers = defaultdict(int)
 
     """ A bit shameful here because we can't really get too much data out of tags because of the way the GH API is implemented.
@@ -232,21 +238,35 @@ def run(gx_context, gx_output):
         gx_output.r_log(message, rtype="tags")
 
 
-    print(f"\rInspecting repository releases.."+" "*40, end="")
+    gx_output.stdout(f"\rInspecting repository releases.."+" "*40, end="")
     releases = gh_api.fetch_repository_releases(repository)
-    if len(releases) > 0: gx_output.r_log(f"{len(releases)} Releases available at: [{repository.get('html_url')}/releases]", rtype="releases")
+    if isinstance(releases, list) and len(releases) > 0: 
+        gx_output.r_log(f"{len(releases)} Releases available at: [{repository.get('html_url')}/releases]", rtype="releases")
 
     release_authors = defaultdict(int)
     asset_uploaders = defaultdict(int)
 
     for release in releases:
-        release_authors[release.get('author').get('login')] += 1
-        gx_output.r_log(f"A release was created by {release.get('author').get('login')} at {release.get('created_at')}: {release.get('html_url')}", rtype="releases")
+        # Particular case in which the GitHub API returns erratic data, mostly happening when not using an auth token
+        # This needs to be fixed at a lower level in our gh_api code, patching here in the meantime.
+        if not isinstance(release, dict):
+            continue
+
+        if release.get('author') == None:
+            author = "NO_USERNAME"
+        else:
+            author = release.get('author').get('login')
+
+        release_authors[author] += 1
+        gx_output.r_log(f"A release was created by {author} at {release.get('created_at')}: {release.get('html_url')}", rtype="releases")
         if len(release.get('assets')) > 0:
             # This release has assets other than frozen code. Let's check if updated_at differs from created_at
             # Which may be an indicator of a compromised release by a malicious actor updating binaries.
             for asset in release.get('assets'):
-                uploaded_by = asset.get('uploader').get('login')
+                if asset.get('uploader') == None:
+                    uploaded_by = "NO_USERNAME"
+                else:
+                    uploaded_by = asset.get('uploader').get('login')
                 asset_uploaders[uploaded_by] += 1
                 created_at = asset.get('created_at')
                 message = f"An asset was uploaded by {uploaded_by} at {created_at}: {asset.get('url')}"
@@ -329,12 +349,13 @@ def run(gx_context, gx_output):
                             print(f"Group length: {len(group)} - Group ID: {group_key}: Range {range_start} to {range_end}, Members: {len(group)}, Logins: {logins}")
         """
 
-    watchers_message = f"Watchers count: [{repository.get('subscribers_count')}]"
-    if repository.get('subscribers_count') > 0:
-        watchers_message += f" List at: {repository.get('subscribers_url')}"
-    gx_output.r_log(watchers_message, rtype="profiling")
+    if repository.get('subscribers_count') is not None:
+        watchers_message = f"Watchers count: [{repository.get('subscribers_count')}]"
+        if repository.get('subscribers_count', 0) > 0:
+            watchers_message += f" List at: {repository.get('subscribers_url')}"
+        gx_output.r_log(watchers_message, rtype="profiling")
 
-    if repository.get('open_issues_count') > 0:
+    if repository.get('open_issues_count', 0) > 0:
         gx_output.r_log(f"Repository has {repository.get('open_issues_count')} Open Issues: {repository.get('html_url')}/issues", rtype="profiling")
 
     if repository.get('description'):
@@ -343,30 +364,32 @@ def run(gx_context, gx_output):
     if repository.get('topics'):
         gx_output.r_log(f"Topics: {str(repository.get('topics'))}", rtype="profiling")
 
-    if repository.get('fork') != False:
+    if repository.get('fork') != False and repository.get('fork') != None:
         parent = repository.get('parent').get('full_name')
         source = repository.get('source').get('full_name')
-        print(f"\rRepository is a FORK of a parent named: {repository.get('parent').get('full_name')}: {repository.get('parent')['html_url']}")
+        gx_output.stdout(f"\rRepository is a FORK of a parent named: {repository.get('parent').get('full_name')}: {repository.get('parent')['html_url']}")
         gx_output.r_log(f"Repository is a FORK of repo: {repository.get('parent')['html_url']}", rtype="fork")
-        print(f"This also means that GitHub will return ALL contributors (might be a LOT) up to the source repository")
+        gx_output.stdout(f"This also means that GitHub will return ALL contributors (might be a LOT) up to the source repository")
         if parent != source:
-            print(f"Please know the parent of this repository is not the original source, which is: {source}") 
+            gx_output.stdout(f"Please know the parent of this repository is not the original source, which is: {source}") 
             gx_output.r_log(f"The parent of this fork comes from SOURCE repo: {repository.get('source')['html_url']}", rtype="fork")
 
 
-    days = (datetime.now(timezone.utc) - gh_time.parse_date(repository.get('created_at'))).days 
-    message = f"{days} days old"
-    if days > 365:
-        years = "{:.2f}".format(days / 365)
-        message = f"{years} years old"
-    gx_output.r_log(f"Repository created: {repository.get('created_at')}, is {message}.", rtype="profiling")
+    if repository.get('created_at') is not None:
+        days = (datetime.now(timezone.utc) - gh_time.parse_date(repository.get('created_at', datetime.utcnow().isoformat()))).days 
+        message = f"{days} days old"
+        if days > 365:
+            years = "{:.2f}".format(days / 365)
+            message = f"{years} years old"
+        gx_output.r_log(f"Repository created: {repository.get('created_at')}, is {message}.", rtype="profiling")
 
-    days = (datetime.now(timezone.utc) - gh_time.parse_date(repository.get('updated_at'))).days 
-    message = f"{days} days ago"
-    if days > 365:
-        years = "{:.2f}".format(days / 365)
-        message = f"{years} years ago"
-    gx_output.r_log(f"Repository last updated: {repository.get('updated_at')}, {message}.", rtype="profiling")
+    if repository.get('updated_at') is not None:
+        days = (datetime.now(timezone.utc) - gh_time.parse_date(repository.get('updated_at', datetime.utcnow().isoformat()))).days 
+        message = f"{days} days ago"
+        if days > 365:
+            years = "{:.2f}".format(days / 365)
+            message = f"{years} years ago"
+        gx_output.r_log(f"Repository last updated: {repository.get('updated_at')}, {message}.", rtype="profiling")
 
     if repository.get('archived') == True:
         gx_output.r_log(f"Repository is archived and therefore likely no longer maintained.", rtype="profiling")
@@ -378,7 +401,7 @@ def run(gx_context, gx_output):
         gx_output.r_log(f"Repository's visibility is set to [private]", rtype="profiling")
 
     public_events = gh_api.fetch_repository_public_events(repository)
-    if len(public_events) > 0:
+    if isinstance(public_events, list) and len(public_events) > 0:
         gh_public_events.log_events(public_events, gx_output, for_repository=True)
 
     if repository.get('organization'):
@@ -394,66 +417,67 @@ def run(gx_context, gx_output):
     submitter_contrib_counts = defaultdict(lambda: {'submitted': 0, 'accepted':0, 'open': 0, 'rejected': 0})
     submitter_notcontrib_counts = defaultdict(lambda: {'submitted': 0, 'accepted':0, 'open': 0, 'rejected': 0})
     clogins = [c.get('login') for c in contributors]
-    for pr in prs:
-        try: # quick ugly patch instead of checking all types are dict and keys exist.
-            submitter = pr['user']['login']
-        except: 
-            continue
-        is_merged = pr['merged_at'] is not None
-        if submitter not in clogins: 
-            submitter_counts = submitter_notcontrib_counts
-        else:
-            submitter_counts = submitter_contrib_counts
-
-        submitter_counts[submitter]['submitted'] += 1
-
-        if is_merged:
-            submitter_counts[submitter]['accepted'] += 1
-        elif pr['state'] == 'closed':
-            submitter_counts[submitter]['rejected'] += 1
-        else:
-            submitter_counts[submitter]['open'] += 1
-
-    for submitter_counts in [submitter_contrib_counts, submitter_notcontrib_counts]:
-        for user, details in submitter_counts.items():
-            if details['submitted'] > 0:
-                # Only add a link to the URL of PRs if it belongs to a user account
-                if user in clogins:
-                    gx_output.c_log(f"{details['submitted']} Pull Requests by [{user}] at: {repository.get('html_url')}/pulls?q=author%3a{user}", rtype="prs", contributor=user)
-                details['rejected_percent'] = (details['rejected'] / details['submitted']) * 100
+    if isinstance(prs, list) and len(prs) > 0:
+        for pr in prs:
+            try: # quick ugly patch instead of checking all types are dict and keys exist.
+                submitter = pr['user']['login']
+            except: 
+                continue
+            is_merged = pr['merged_at'] is not None
+            if submitter not in clogins: 
+                submitter_counts = submitter_notcontrib_counts
             else:
-                details['rejected_percent'] = 0
+                submitter_counts = submitter_contrib_counts
+    
+            submitter_counts[submitter]['submitted'] += 1
 
-            # Used GPT for this, we're automathgically weighting amount AND percentage, and it appears to be working.
-            details['rejected_score'] = details['rejected_percent'] * math.log1p(details['rejected'])
+            if is_merged:
+                submitter_counts[submitter]['accepted'] += 1
+            elif pr['state'] == 'closed':
+                submitter_counts[submitter]['rejected'] += 1
+            else:
+                submitter_counts[submitter]['open'] += 1
 
-    sorted_submitters_contrib_rejected = sorted(submitter_contrib_counts.items(), key=lambda x: (-x[1]['rejected_score'], -x[1]['submitted']))
-    sorted_submitters_notcontrib_rejected = sorted(submitter_notcontrib_counts.items(), key=lambda x: (-x[1]['rejected_score'], -x[1]['submitted']))
+        for submitter_counts in [submitter_contrib_counts, submitter_notcontrib_counts]:
+            for user, details in submitter_counts.items():
+                if details['submitted'] > 0:
+                    # Only add a link to the URL of PRs if it belongs to a user account
+                    if user in clogins:
+                        gx_output.c_log(f"{details['submitted']} Pull Requests by [{user}] at: {repository.get('html_url')}/pulls?q=author%3a{user}", rtype="prs", contributor=user)
+                    details['rejected_percent'] = (details['rejected'] / details['submitted']) * 100
+                else:
+                    details['rejected_percent'] = 0
+    
+                # Used GPT for this, we're automathgically weighting amount AND percentage, and it appears to be working.
+                details['rejected_score'] = details['rejected_percent'] * math.log1p(details['rejected'])
+   
+        sorted_submitters_contrib_rejected = sorted(submitter_contrib_counts.items(), key=lambda x: (-x[1]['rejected_score'], -x[1]['submitted']))
+        sorted_submitters_notcontrib_rejected = sorted(submitter_notcontrib_counts.items(), key=lambda x: (-x[1]['rejected_score'], -x[1]['submitted']))
 
-    # First loop on top 3 to log in Repository output
-    message = []
-    for user, details in sorted_submitters_contrib_rejected[:3]:
-        if details['rejected'] > 0:
-            message.append(f"[{user} {details['rejected']} rejected out of {details['submitted']}]")
-    if len(message) > 0:
-        gx_output.r_log(f"Top repository contributors with rejected PRs: " + " | ".join(message), rtype="contributors")
+        # First loop on top 3 to log in Repository output
+        message = []
+        for user, details in sorted_submitters_contrib_rejected[:3]:
+            if details['rejected'] > 0:
+                message.append(f"[{user} {details['rejected']} rejected out of {details['submitted']}]")
+        if len(message) > 0:
+            gx_output.r_log(f"Top repository contributors with rejected PRs: " + " | ".join(message), rtype="contributors")
 
-    # Now for NON contributors
-    message = []
-    for user, details in sorted_submitters_notcontrib_rejected[:3]:
-        if details['rejected'] > 0:
-            message.append(f"[{user} {details['rejected']} rejected out of {details['submitted']}]")
-    if len(message) > 0:
-        gx_output.r_log(f"Top non-contributor GitHub users with rejected PRs: " + " | ".join(message), rtype="contributors")
+        # Now for NON contributors
+        message = []
+        for user, details in sorted_submitters_notcontrib_rejected[:3]:
+            if details['rejected'] > 0:
+                message.append(f"[{user} {details['rejected']} rejected out of {details['submitted']}]")
+        if len(message) > 0:
+            gx_output.r_log(f"Top non-contributor GitHub users with rejected PRs: " + " | ".join(message), rtype="contributors")
 
-    # And now loop on all to log under each user account.
-    for user, details in submitter_contrib_counts.items():
-        if details['rejected'] > 0:
-            gx_output.c_log(f"The user submitted {details['submitted']} Pull Requests out of which {details['rejected']} were rejected.", rtype="profiling", contributor=user)
-        if details['accepted'] > 0:
-            gx_output.c_log(f"The user submitted {details['submitted']} Pull Requests out of which {details['accepted']} were merged.", rtype="profiling", contributor=user)
-        if details['open'] > 0:
-            gx_output.c_log(f"The user submitted {details['submitted']} Pull Requests out of which {details['open']} remain open.", rtype="profiling", contributor=user)
+        # And now loop on all to log under each user account.
+        for user, details in submitter_contrib_counts.items():
+            if details['rejected'] > 0:
+                gx_output.c_log(f"The user submitted {details['submitted']} Pull Requests out of which {details['rejected']} were rejected.", rtype="profiling", contributor=user)
+            if details['accepted'] > 0:
+                gx_output.c_log(f"The user submitted {details['submitted']} Pull Requests out of which {details['accepted']} were merged.", rtype="profiling", contributor=user)
+            if details['open'] > 0:
+                gx_output.c_log(f"The user submitted {details['submitted']} Pull Requests out of which {details['open']} remain open.", rtype="profiling", contributor=user)
 
     # Check if there were any users with mismatches in commits dates in the repository.
     for user, dates_mismatch_commits in gx_context.getIdentifierValues("DATE_MISMATCH_COMMITS").items():
